# Generated by Django 2.1.3 on 2018-11-15 15:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('geonames_place', '0003_place_update_from_geonames'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='country',
            options={'ordering': ['name', 'code'], 'verbose_name_plural': 'Countries'},
        ),
    ]
